==> kdevplatform-0.9.83.tar.bz2: kdevplatform-0.9.83/kdevplatformversion.h.cmake <==
/*****************************************************************************
 * This file is part of the KDE project
 * Copyright 2008 Andreas Pakulat <apaku@gmx.de>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 *******************************************************************************/
#ifndef KDEVPLATFORM_VERSION_H
#define KDEVPLATFORM_VERSION_H

#include <kdeversion.h>

#define KDEVPLATFORM_MAJOR_VERSION @KDevPlatform_VERSION_MAJOR@
#define KDEVPLATFORM_MINOR_VERSION @KDevPlatform_VERSION_MINOR@
#define KDEVPLATFORM_PATCH_VERSION @KDevPlatform_VERSION_PATCH@

#define KDEVPLATFORM_VERSION_STR "@KDevPlatform_VERSION_MAJOR@.@KDevPlatform_VERSION_MINOR@.@KDevPlatform_VERSION_PATCH@"

#define KDEVPLATFORM_VERSION KDE_MAKE_VERSION(@KDevPlatform_VERSION_MAJOR@, @KDevPlatform_VERSION_MINOR@, @KDevPlatform_VERSION_PATCH@)

#endif

==> kdevplatform_1.7.3.orig.tar.bz2: kdevplatform-1.7.3/kdevplatformversion.h.cmake <==
/*****************************************************************************
 * This file is part of the KDE project
 * Copyright 2008 Andreas Pakulat <apaku@gmx.de>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 *******************************************************************************/
#ifndef KDEVPLATFORM_VERSION_H
#define KDEVPLATFORM_VERSION_H

#include <kdeversion.h>

#define KDEVPLATFORM_MAJOR_VERSION @KDEVPLATFORM_VERSION_MAJOR@
#define KDEVPLATFORM_MINOR_VERSION @KDEVPLATFORM_VERSION_MINOR@
#define KDEVPLATFORM_PATCH_VERSION @KDEVPLATFORM_VERSION_PATCH@

#define KDEVPLATFORM_VERSION_STR "@KDEVPLATFORM_VERSION_MAJOR@.@KDEVPLATFORM_VERSION_MINOR@.@KDEVPLATFORM_VERSION_PATCH@"

#define KDEVPLATFORM_VERSION KDE_MAKE_VERSION(@KDEVPLATFORM_VERSION_MAJOR@, @KDEVPLATFORM_VERSION_MINOR@, @KDEVPLATFORM_VERSION_PATCH@)

#endif
